@@ -1,16 +1,17 @@
 package Net::RackSpace::CloudServers::Flavor;
-our $VERSION = '0.05_00';
+our $VERSION = '0.06_00';
 
 use warnings;
 use strict;
 use Moose;
 use MooseX::StrictConstructor;
 
-has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'id'           => ( is => 'ro', isa => 'Int',                          required => 1 );
-has 'name'         => ( is => 'ro', isa => 'Str',                          required => 1 );
-has 'ram'          => ( is => 'ro', isa => 'Maybe[Int]',                   required => 1 );
-has 'disk'         => ( is => 'ro', isa => 'Maybe[Int]',                   required => 1 );
+has 'cloudservers' =>
+  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
+has 'id'   => ( is => 'ro', isa => 'Int',        required => 1 );
+has 'name' => ( is => 'ro', isa => 'Str',        required => 1 );
+has 'ram'  => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
+has 'disk' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
 
 no Moose;
 __PACKAGE__->meta->make_immutable();
@@ -21,7 +22,7 @@ Net::RackSpace::CloudServers::Flavor - a RackSpace CloudServers Flavor
 
 =head1 VERSION
 
-version 0.05_00
+version 0.06_00
 
 =head1 SYNOPSIS
 
