@@ -1,19 +1,20 @@
 package Net::RackSpace::CloudServers::Image;
-our $VERSION = '0.05_00';
+our $VERSION = '0.06_00';
 
 use warnings;
 use strict;
 use Moose;
 use MooseX::StrictConstructor;
 
-has 'cloudservers' => ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
-has 'id'           => ( is => 'ro', isa => 'Int',                          required => 1 );
-has 'name'         => ( is => 'ro', isa => 'Str',                          required => 1 );
-has 'serverid'     => ( is => 'ro', isa => 'Maybe[Int]',                   required => 1 );
-has 'updated'      => ( is => 'ro', isa => 'Maybe[Str]',                   required => 1 );
-has 'created'      => ( is => 'ro', isa => 'Maybe[Str]',                   required => 1 );
-has 'status'       => ( is => 'ro', isa => 'Maybe[Str]',                   required => 1 );
-has 'progress'     => ( is => 'ro', isa => 'Maybe[Int]',                   required => 1 );
+has 'cloudservers' =>
+  ( is => 'rw', isa => 'Net::RackSpace::CloudServers', required => 1 );
+has 'id'       => ( is => 'ro', isa => 'Int',        required => 1 );
+has 'name'     => ( is => 'ro', isa => 'Str',        required => 1 );
+has 'serverid' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
+has 'updated'  => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
+has 'created'  => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
+has 'status'   => ( is => 'ro', isa => 'Maybe[Str]', required => 1 );
+has 'progress' => ( is => 'ro', isa => 'Maybe[Int]', required => 1 );
 
 no Moose;
 __PACKAGE__->meta->make_immutable();
@@ -24,7 +25,7 @@ Net::RackSpace::CloudServers::Image - a RackSpace CloudServers Image
 
 =head1 VERSION
 
-version 0.05_00
+version 0.06_00
 
 =head1 SYNOPSIS
 
